@@ -5,13 +5,13 @@ test_that("OVL.K() returns a list", {
 
 test_that("OVL.K() returns a valid result", {
   output_list <- OVL.K(x=test_data$controls,y=test_data$cases)
-  expect_true( output_list[[1]]>= 0.3 & output_list[[2]] <= 1)
+  expect_true(output_list[[1]] <= output_list[[2]] & output_list[[1]] >= 0 & output_list[[2]]<=1)
 })
 
 test_that("OVL.K() returns a valid result", {
   set.seed(1)
   output_list <- OVL.K(x=rnorm(50,0,1),y=rnorm(50,0.5,0.5),k=2)
-  expect_true( output_list[[1]]>= 0.3 & output_list[[2]] <= 1)
+  expect_true(output_list[[1]] <= output_list[[2]] & output_list[[1]] >= 0 & output_list[[2]]<=1)
 })
 
 test_that("OVL.K() returns a list", {
